#
# spec file for package python-semantic_version
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} == 1600 || 0%{?suse_version} <= 1550
# No django in SLFO:Main
%bcond_with django
%else
%bcond_without django
%endif

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-semantic_version%{psuffix}
Version:        2.10.0
Release:        4.2
Summary:        A library implementing the 'SemVer' scheme
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/rbarrois/python-semanticversion
Source:         https://files.pythonhosted.org/packages/source/s/semantic_version/semantic_version-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module pytest}
%if %{with django}
# Django 4.0 dropped support for Python < 3.8
BuildRequires:  %{python_module Django >= 1.11 if (%python-base without python36-base)}
%endif
%endif
%python_subpackages

%description
This small python library provides a few tools to handle `SemVer`_ in Python.
It follows strictly the 2.0.0 version of the SemVer scheme.

%prep
%autosetup -n semantic_version-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%if %{without django}
python_flags="--ignore tests/test_django.py"
%else
# Django 4.0 dropped support for Python < 3.8
python36_flags="--ignore tests/test_django.py"
%endif

%pytest ${$python_flags} ${python_flags}

%else

%files %{python_files}
%license LICENSE
%doc README.rst ChangeLog
%{python_sitelib}/semantic_version
%{python_sitelib}/semantic_version-%{version}*-info
%endif

%changelog
* Tue Oct  1 2024 Daniel Garcia <daniel.garcia@suse.com>
- Make Django build-requirement conditional and disable by default for
  SUSE:SLFO:Main, bsc#1231124
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Feb 17 2023 Matej Cepl <mcepl@suse.com>
- Test with Django only with Factory
* Sun May 29 2022 Torsten Gruner <simmphonie@opensuse.org>
- update to 2.10.0
  * `132 <https://github.com/rbarrois/python-semanticversion/issues/132>`_:
    Ensure sorting a collection of versions is always stable, even with
    build metadata.
- version 2.9.0
  * Add support for Django 3.1, 3.2, 4.0
  * Add support for Python 3.7 / 3.8 / 3.9 / 3.10
- remove sematicversion-pr123-dj40.patch
* Mon Dec 27 2021 Ben Greiner <code@bnavigator.de>
- Make it work with Django 4
  * add sematicversion-pr123-dj40.patch
  * gh#rbarrois/python-semanticversion#123
  * Don't test django app on python36: Django 4 dropped it
* Fri Dec 10 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add the package suffix to Name to have multibuild work correctly.
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- split tests into flavor to avoid build cycle with djang
* Wed Jul 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2.8.5
  * Properly handle wildcards in ``SimpleSpec``
* Wed Mar 18 2020 pgajdos@suse.com
- version update to 2.8.4
  * `#89 <https://github.com/rbarrois/python-semanticversion/issues/89>`_:
    Properly coerce versions with leading zeroes in components (e.g.
    ``1.01.007``)
  - Add `Clause.prettyprint()` for debugging
  * `#86 <https://github.com/rbarrois/python-semanticversion/issues/86>`_:
    Fix handling of prerelease ranges within `NpmSpec`
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.8.2:
  * various major parsing fixes
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Aug 22 2017 tbechtold@suse.com
- update to 2.6.0:
  * Add support for Django up to 1.10.
  * Remove support for Django<1.7
  * Properly handle `^0.X.Y` in a NPM-compatible way
  * According to SemVer 2.0.0, build numbers aren't ordered.
  * Remove specs of the ``Spec('<1.1.3+')`` form
  * Comparing ``Version('0.1.0')`` to ``Version('0.1.0+bcd')`` has new
    rules
  * :func:`semantic_version.compare` returns ``NotImplemented`` when its
    parameters differ only by build metadata
  * ``Spec('<=1.3.0')`` now matches ``Version('1.3.0+abde24fe883')``
  * Fix handling of bumping pre-release versions, thanks to @minchinweb.
  * Add support for NPM-style ``^1.2.3`` and ``~2.3.4`` specs, thanks to @skwashd
  * Fix tests for Django 1.7+, thanks to @mhrivnak.
- convert to singlespec
* Wed Jul 22 2015 dmueller@suse.com
- fix license
* Tue Apr 28 2015 tbechtold@suse.com
- Initial packaging
